Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func AllShortcuts ¶
AllShortcuts returns a copy of all registered shortcuts (for dump-shortcuts).
func IsShortcutServiceAvailable ¶ added in v1.0.38
func RegisterShortcuts ¶
RegisterShortcuts registers all +shortcut commands on the program.
Types ¶
This section is empty.
Directories
¶
| Path | Synopsis |
|---|---|
|
emlbuilder
Package emlbuilder provides a Lark-API-compatible RFC 2822 EML message builder.
|
Package emlbuilder provides a Lark-API-compatible RFC 2822 EML message builder. |
|
filecheck
Package filecheck provides mail attachment file validation utilities shared by the emlbuilder and draft packages.
|
Package filecheck provides mail attachment file validation utilities shared by the emlbuilder and draft packages. |
|
ics
Package ics provides RFC 5545 iCalendar generation and parsing for mail calendar invitations.
|
Package ics provides RFC 5545 iCalendar generation and parsing for mail calendar invitations. |
|
lint
Package lint implements the mail-domain HTML lint lib used by `+lint-html` and the writing-path internals of the compose 5 shortcuts (`+send`, `+draft-create`, `+reply`, `+reply-all`, `+forward`) and `+draft-edit` body ops.
|
Package lint implements the mail-domain HTML lint lib used by `+lint-html` and the writing-path internals of the compose 5 shortcuts (`+send`, `+draft-create`, `+reply`, `+reply-all`, `+forward`) and `+draft-edit` body ops. |
Click to show internal directories.
Click to hide internal directories.