shortcuts

package
v1.0.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 28, 2026 License: MIT Imports: 16 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func AllShortcuts

func AllShortcuts() []common.Shortcut

AllShortcuts returns a copy of all registered shortcuts (for dump-shortcuts).

func RegisterShortcuts

func RegisterShortcuts(program *cobra.Command, f *cmdutil.Factory)

RegisterShortcuts registers all +shortcut commands on the program.

Types

This section is empty.

Directories

Path Synopsis
im
emlbuilder
Package emlbuilder provides a Lark-API-compatible RFC 2822 EML message builder.
Package emlbuilder provides a Lark-API-compatible RFC 2822 EML message builder.
filecheck
Package filecheck provides mail attachment file validation utilities shared by the emlbuilder and draft packages.
Package filecheck provides mail attachment file validation utilities shared by the emlbuilder and draft packages.

Jump to